#ifndef TESTPLUGIN_H
#define TESTPLUGIN_H

#include <QObject>
#include <QStringList>
#include <QImage>

#include <mbarcode-qt/plugininterfaces.h>

class PluginAction;
class MaemoBarcodeWindow;
class QrSink;

class QrPlugin : public QObject, public PluginInterface
{
    Q_OBJECT
    Q_INTERFACES(PluginInterface)
public:
    void initInterface(QWidget *parent);
    QSet<PluginAction*> getPluginActions();
    QString getName() {return "QR-Code opener";}
private:
    MaemoBarcodeWindow *parent;
    QString url;
    QrSink *sink;
};

#endif //TESTPLUGIN_H
